"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const del_1 = __importDefault(require("del"));
const execa_1 = __importDefault(require("execa"));
const fs_1 = __importDefault(require("fs"));
const moment_1 = __importDefault(require("moment"));
const path_1 = __importDefault(require("path"));
const prettier_1 = __importDefault(require("prettier"));
const prettier_package_json_1 = __importDefault(require("prettier-package-json"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const RearguardDevConfig_1 = require("../../configs/RearguardDevConfig");
const const_1 = require("../../const");
const processQueue_1 = require("../../helpers/processQueue");
const buildNodeApp_1 = require("../procedures/build/buildNodeApp");
const buildUnfinishedDependencies_1 = require("../procedures/build/buildUnfinishedDependencies");
const copyGlobalLinkedModules_1 = require("../procedures/copyGlobalLinkedModules");
async function build_node_app(options) {
    console.log(chalk_1.default.bold.blue(`[ NODE ][ APP ][ BUILD ][ START ]`));
    console.log("");
    const startTime = moment_1.default();
    const CWD = process.cwd();
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const rearguardLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(CWD);
    const pkg = rearguardConfig.getPkg();
    const name = rearguardConfig.getName();
    await processQueue_1.processQueue.getInQueue(name, options.bypass_the_queue);
    await rearguardLocalConfig.setBuildStatus("in_progress");
    const paths = await del_1.default([path_1.default.resolve(CWD, const_1.DISTRIBUTIVE_DIR_NAME)]);
    if (paths.length > 0) {
        for (const item of paths) {
            console.log(chalk_1.default.gray(`[ REMOVE ][ ${path_1.default.relative(CWD, item)} ]`));
        }
        console.log("");
    }
    await buildUnfinishedDependencies_1.buildUnfinishedDependencies(CWD);
    await copyGlobalLinkedModules_1.copyGlobalLinkedModules(CWD);
    await buildNodeApp_1.buildNodeApp(CWD);
    console.log(chalk_1.default.bold.blue(`[ COPY PKG TO DIST AND INSTALL DEPS FOR PRODUCTION ]`));
    console.log("");
    const prodPkg = {
        private: true,
        engines: pkg.engines,
        dependencies: pkg.dependencies,
    };
    const prodPkgFormatedJSON = JSON.parse(prettier_package_json_1.default.format(prodPkg));
    const prodPkgPath = path_1.default.resolve(CWD, const_1.DISTRIBUTIVE_DIR_NAME, "package.json");
    const prodPkgContent = prettier_1.default.format(JSON.stringify(prodPkgFormatedJSON), const_1.PRETTIER_JSON_STRINGIFY);
    fs_1.default.writeFileSync(prodPkgPath, prodPkgContent);
    try {
        const execaOptions = {
            cwd: path_1.default.resolve(CWD, const_1.DISTRIBUTIVE_DIR_NAME),
            stdout: "inherit",
            stderr: "inherit",
        };
        await execa_1.default("npm", ["install", "--production"], execaOptions);
    }
    catch (error) {
        console.error(error);
    }
    await rearguardLocalConfig.setBuildStatus("done");
    await processQueue_1.processQueue.getOutQueue(name, options.bypass_the_queue);
    console.log("");
    console.log(chalk_1.default.bold.blue(`[ NODE ][ APP ][ BUILD ][ FINISH ][ ${moment_1.default().diff(startTime, "milliseconds")} ms ]`));
    console.log("");
}
exports.build_node_app = build_node_app;
//# sourceMappingURL=build_node_app.js.map