"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const updateVSCodeSettingsForMonoRepo_1 = require("../procedures/updateVSCodeSettingsForMonoRepo");
const build_browser_app_1 = require("./build_browser_app");
const build_browser_dll_1 = require("./build_browser_dll");
const build_browser_lib_1 = require("./build_browser_lib");
const build_isomorphic_1 = require("./build_isomorphic");
const build_node_app_1 = require("./build_node_app");
const build_node_lib_1 = require("./build_node_lib");
const defaultOptions = {
    only_dev: false,
    debug: false,
    need_update_build_time: false,
    bypass_the_queue: false,
};
async function build_component(options = defaultOptions) {
    const CWD = process.cwd();
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const isIsomorphic = rearguardConfig.isIsomorphic();
    const isBrowser = rearguardConfig.isBrowser();
    const isNode = rearguardConfig.isNode();
    const isApp = rearguardConfig.isApp();
    const isLib = rearguardConfig.isLib();
    const isDll = rearguardConfig.isDll();
    await updateVSCodeSettingsForMonoRepo_1.updateVSCodeSettingsForMonoRepo(CWD);
    if (isIsomorphic) {
        await build_isomorphic_1.build_isomorphic(options);
    }
    if (isBrowser && isDll) {
        await build_browser_dll_1.build_browser_dll(options);
    }
    if (isBrowser && isLib) {
        await build_browser_lib_1.build_browser_lib(options);
    }
    if (isBrowser && isApp) {
        await build_browser_app_1.build_browser_app(options);
    }
    if (isNode && isLib) {
        await build_node_lib_1.build_node_lib(options);
    }
    if (isNode && isApp) {
        await build_node_app_1.build_node_app(options);
    }
}
exports.build_component = build_component;
//# sourceMappingURL=index.js.map