"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const execa_1 = __importDefault(require("execa"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const getSortedListOfDependencies_1 = require("../procedures/getSortedListOfDependencies");
const processQueue_1 = require("../../helpers/processQueue");
exports.group_bootstrap_component = async (options) => {
    const CWD = process.cwd();
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const name = rearguardConfig.getName();
    const components = rearguardConfig.getComponents();
    await processQueue_1.processQueue.getInQueue(name);
    const sortedListOfMonoComponents = await getSortedListOfDependencies_1.getSortedListOfMonoComponents(CWD, components);
    for (const pathToComponent of sortedListOfMonoComponents) {
        const execaOptions = {
            stdout: "inherit",
            stderr: "inherit",
            cwd: pathToComponent,
        };
        const rearguardConfigItem = new RearguardConfig_1.RearguardConfig(pathToComponent);
        const isDll = rearguardConfigItem.isDll();
        console.log(chalk_1.default.bold.blue(`[ ${pathToComponent} ]`));
        console.log("");
        await execa_1.default("rm", ["-rf", "./node_modules"], execaOptions);
        await execa_1.default("npm", ["install"], execaOptions);
        await execa_1.default("npm", ["link"], execaOptions);
        await execa_1.default("npm", ["run", "sync", "--", "--bypass_the_queue"], execaOptions);
        if (!isDll) {
            await execa_1.default("npm", ["run", "validate"], execaOptions);
        }
        await execa_1.default("npm", [
            "run",
            "build",
            ...(options.debug ? ["--", "--debug"] : []),
            ...(options.only_dev ? ["--", "--only_dev"] : []),
            ...["--", "--bypass_the_queue"],
        ], execaOptions);
        console.log("");
    }
    await processQueue_1.processQueue.getOutQueue(name);
};
//# sourceMappingURL=group_bootstrap_component.js.map