"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const updateVSCodeSettingsForMonoRepo_1 = require("../procedures/updateVSCodeSettingsForMonoRepo");
const init_browser_app_1 = require("./init_browser_app");
const init_browser_dll_1 = require("./init_browser_dll");
const init_browser_lib_1 = require("./init_browser_lib");
const init_isomorphic_1 = require("./init_isomorphic");
const init_mono_1 = require("./init_mono");
const init_node_app_1 = require("./init_node_app");
const init_node_lib_1 = require("./init_node_lib");
const defaultOptions = {
    dll: false,
    browser: false,
    node: false,
    app: false,
    lib: false,
    mono: false,
    force: false,
};
async function init_component(options = defaultOptions) {
    if (options.dll) {
        await init_browser_dll_1.init_browser_dll({ force: options.force });
    }
    if (options.browser && !options.node) {
        if (options.app) {
            await init_browser_app_1.init_browser_app({ force: options.force });
        }
        if (options.lib) {
            await init_browser_lib_1.init_browser_lib({ force: options.force });
        }
    }
    if (!options.browser && options.node) {
        if (options.app) {
            await init_node_app_1.init_node_app({ force: options.force });
        }
        if (options.lib) {
            await init_node_lib_1.init_node_lib({ force: options.force });
        }
    }
    if (options.browser && options.node) {
        await init_isomorphic_1.init_isomorphic({ force: options.force });
    }
    if (options.mono) {
        await init_mono_1.init_mono({ force: options.force });
    }
    await updateVSCodeSettingsForMonoRepo_1.updateVSCodeSettingsForMonoRepo(process.cwd());
}
exports.init_component = init_component;
//# sourceMappingURL=index.js.map