"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const execa_1 = __importDefault(require("execa"));
const path_1 = __importDefault(require("path"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const const_1 = require("../../const");
const mkdir_1 = require("../../helpers/mkdir");
const gitignore_1 = require("../../templates/gitignore");
const prettierignore_1 = require("../../templates/prettierignore");
const prettierrc_1 = require("../../templates/prettierrc");
const vsCode_1 = require("../../templates/vsCode");
const initPackage_1 = require("../procedures/initPackage");
async function init_mono(flags) {
    const CWD = process.cwd();
    const execaOptions = {
        stdout: "inherit",
        stderr: "inherit",
    };
    await initPackage_1.initPackage(CWD);
    await execa_1.default("npm", ["install", "-D", "husky"], execaOptions);
    await mkdir_1.mkdir(path_1.default.resolve(CWD, "components"));
    await vsCode_1.vsCodeSettingsTemplate.render(flags);
    await vsCode_1.vsCodeExtensionsTemplate.render(flags);
    await prettierrc_1.prettierTemplate.render(flags);
    await prettierignore_1.prettierIgnoreTemplate.render(flags);
    await gitignore_1.gitignoreTemplate.render({
        publish_to_git: false,
        list_for_load_on_demand: const_1.LIST_OF_LOAD_ON_DEMAND,
        force: flags.force,
    });
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    await rearguardConfig.setType("mono");
    await rearguardConfig.setComponents(["components"]);
    await rearguardConfig.setScripts({
        bootstrap: "rearguard group bootstrap",
        clear: "rearguard group clear",
        link: "rearguard group link",
        lint: "rearguard group lint",
        start: "rearguard group start",
        ["lint-fix"]: "rearguard group lint-fix",
        typecheck: "rearguard group typecheck",
        ["validate-prettiness"]: "rearguard group validate-prettiness",
        validate: "rearguard group validate",
        ["make-prettier"]: "rearguard group make-prettier",
        build: "rearguard group build",
        test: "rearguard group test",
        publish: "rearguard group publish",
        refresh: "rearguard group refresh",
        sync: "rearguard group sync",
    }, true);
}
exports.init_mono = init_mono;
//# sourceMappingURL=init_mono.js.map