"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const execa_1 = __importDefault(require("execa"));
const targetDepKeys = ["tslib"];
const targetDevDepKeys = [
    "typescript",
    "prettier",
    "pretty-quick",
    "husky",
    "eslint",
    "eslint-config-prettier",
    "@typescript-eslint/parser",
    "@typescript-eslint/eslint-plugin",
];
exports.checkDependencies = async (CWD = process.cwd()) => {
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const isBrowser = rearguardConfig.isBrowser();
    const isIsomorphic = rearguardConfig.isIsomorphic();
    if (isBrowser || isIsomorphic) {
        targetDevDepKeys.push("eslint-plugin-react");
        targetDevDepKeys.push("normalize.css");
        targetDevDepKeys.push("stylelint");
        targetDevDepKeys.push("stylelint-config-standard");
        targetDevDepKeys.push("stylelint-config-prettier");
        targetDevDepKeys.push("stylelint-config-css-modules");
    }
    const depMap = rearguardConfig.getDependencies();
    const depKeys = Object.keys(depMap);
    const devDepMap = rearguardConfig.getDevDependencies();
    const devDepKeys = Object.keys(devDepMap);
    const targetDepMap = {};
    const targetDevDepMap = {};
    for (const depKey of depKeys) {
        if (!targetDevDepKeys.includes(depKey)) {
            targetDepMap[depKey] = depMap[depKey];
        }
    }
    for (const devDepKey of devDepKeys) {
        if (!targetDepKeys.includes(devDepKey)) {
            targetDevDepMap[devDepKey] = devDepMap[devDepKey];
        }
    }
    rearguardConfig.setDependencies(targetDepMap);
    rearguardConfig.setDevDependencies(targetDevDepMap);
    const needInstallDeps = targetDepKeys.some((name) => !depKeys.includes(name));
    const needInstallDevDeps = targetDevDepKeys.some((name) => !devDepKeys.includes(name));
    const execaOptions = {
        stdout: "inherit",
        stderr: "inherit",
    };
    if (needInstallDeps) {
        try {
            const curDepList = rearguardConfig.getDependencyList();
            const toInstall = targetDepKeys.filter((name) => !curDepList.includes(name));
            await execa_1.default("npm", ["install", "-S", ...toInstall], execaOptions);
        }
        catch (error) {
            console.error(error);
        }
    }
    if (needInstallDevDeps) {
        try {
            const curDevDepList = rearguardConfig.getDevDependencyList();
            const toInstall = targetDevDepKeys.filter((name) => !curDevDepList.includes(name));
            await execa_1.default("npm", ["install", "-D", ...toInstall], execaOptions);
        }
        catch (error) {
            console.error(error);
        }
    }
    if (needInstallDeps || needInstallDevDeps) {
        await execa_1.default("npx", ["typesync"], execaOptions);
    }
    await rearguardConfig.reformat();
};
//# sourceMappingURL=checkDependencies.js.map