"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const copy_1 = __importDefault(require("copy"));
const del_1 = __importDefault(require("del"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const const_1 = require("../../const");
const dependencyPaths_1 = require("../../helpers/dependencyPaths");
const mkdir_1 = require("../../helpers/mkdir");
const getSortedListOfDependencies_1 = require("./getSortedListOfDependencies");
exports.copyBundlesToProject = async (CWD) => {
    const dependencies = await getSortedListOfDependencies_1.getSortedListOfDependencies(CWD);
    if (dependencies.length === 0) {
        return;
    }
    console.log(chalk_1.default.bold.blue(`[ COPY BUNDLES FORM LOCAL NODE_MODULES TO PROJECT ]`));
    console.log("");
    const localNodeModulePath = dependencyPaths_1.getLocalNodeModulePath(CWD);
    for (const dependency of dependencies) {
        const dependencyLocalPath = path_1.default.resolve(localNodeModulePath, dependency);
        const rearguardConfig = new RearguardConfig_1.RearguardConfig(dependencyLocalPath);
        const snakeName = rearguardConfig.getSnakeName();
        const dllSource = path_1.default.resolve(dependencyLocalPath, const_1.DLL_BUNDLE_DIR_NAME, snakeName);
        const libSource = path_1.default.resolve(dependencyLocalPath, const_1.LIB_BUNDLE_DIR_NAME, snakeName);
        const dllDestination = path_1.default.resolve(CWD, const_1.DLL_BUNDLE_DIR_NAME, snakeName);
        const libDestination = path_1.default.resolve(CWD, const_1.LIB_BUNDLE_DIR_NAME, snakeName);
        if (fs_1.default.existsSync(dllDestination)) {
            const paths = await del_1.default(dllDestination);
            for (const item of paths) {
                const relativePath = path_1.default.relative(process.cwd(), item);
                console.log(chalk_1.default.gray(`[ REMOVE ][ DLL ][ BUNDLE ][ DIR ][ ${snakeName} ][ ${relativePath} ]`));
            }
        }
        if (fs_1.default.existsSync(dllSource)) {
            mkdir_1.mkdir(dllDestination);
            const relativePath = path_1.default.relative(process.cwd(), dllDestination);
            console.log(chalk_1.default.green(`[ CREATED ][ DLL ][ BUNDLE ][ DIR ][ ${snakeName} ][ ${relativePath} ]`));
        }
        await new Promise((resolve, reject) => {
            copy_1.default([`${dllSource}/**`], dllDestination, (error, files) => {
                if (!error) {
                    if (files && files.length > 0) {
                        console.log(chalk_1.default.cyan(`[ COPY    ][ DLL ][ BUNDLE ][ ${snakeName} ][ ${files.length} FILES ]`));
                    }
                    resolve();
                }
                else {
                    reject(error);
                }
            });
        });
        if (fs_1.default.existsSync(libDestination)) {
            const paths = await del_1.default(libDestination);
            for (const item of paths) {
                const relativePath = path_1.default.relative(process.cwd(), item);
                console.log(chalk_1.default.gray(`[ REMOVE ][ LIB ][ BUNDLE ][ DIR ][ ${snakeName} ][ ${relativePath} ]`));
            }
        }
        if (fs_1.default.existsSync(libSource)) {
            mkdir_1.mkdir(libDestination);
            const relativePath = path_1.default.relative(process.cwd(), libDestination);
            console.log(chalk_1.default.green(`[ CREATED ][ LIB ][ BUNDLE ][ DIR ][ ${snakeName} ][ ${relativePath} ]`));
        }
        await new Promise((resolve, reject) => {
            copy_1.default([`${libSource}/**`], libDestination, (error, files) => {
                if (!error) {
                    if (files && files.length > 0) {
                        console.log(chalk_1.default.cyan(`[ COPY    ][ LIB ][ BUNDLE ][ ${snakeName} ][ ${files.length} FILES ]`));
                    }
                    resolve();
                }
                else {
                    reject(error);
                }
            });
        });
    }
    console.log("");
};
//# sourceMappingURL=copyBundlesToProject.js.map