"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const prettier_1 = __importDefault(require("prettier"));
const getBundleIntrospection_1 = require("./getBundleIntrospection");
const const_1 = require("../../const");
const RearguardConfig_1 = require("../../configs/RearguardConfig");
exports.createListModulesForLoadOnDemand = async (CWD, isDevelopment) => {
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const bundleIntrospections = await getBundleIntrospection_1.getBundleIntrospections(CWD, isDevelopment);
    const listModulesForLoadOnDemandPath = path_1.default.resolve(CWD, rearguardConfig.getContext(), const_1.LIST_OF_LOAD_ON_DEMAND);
    let source = "/* eslint:disable */\r";
    let needWrite = false;
    for (const { pkgSnakeName, willLoadOnDemand, hasDll, hasBrowserLib, assetsPath, bundleRuntimeName, } of bundleIntrospections) {
        if (willLoadOnDemand) {
            if (hasDll && hasBrowserLib) {
                if (fs_1.default.existsSync(assetsPath.dll) && fs_1.default.existsSync(assetsPath.lib)) {
                    const dllPublicPath = require(assetsPath.dll)[bundleRuntimeName.dll].js;
                    const libPublicPath = require(assetsPath.lib)[bundleRuntimeName.lib].js;
                    source +=
                        `export const ${pkgSnakeName}: { dll: string[], lib: string[] } = ` +
                            `{ dll: [ "${bundleRuntimeName.dll}" , "${dllPublicPath}" ], lib: [ "${bundleRuntimeName.lib}", "${libPublicPath}" ] } \r`;
                    needWrite = true;
                }
            }
            if (!hasDll && hasBrowserLib) {
                if (fs_1.default.existsSync(assetsPath.lib)) {
                    const libPublicPath = require(assetsPath.lib)[bundleRuntimeName.lib].js;
                    source += `export const ${pkgSnakeName} = { lib: [ "${bundleRuntimeName.lib}", "${libPublicPath}" ] } \r`;
                    needWrite = true;
                }
            }
        }
    }
    source += "/* eslint:enable */\r\n";
    if (needWrite) {
        fs_1.default.writeFileSync(listModulesForLoadOnDemandPath, prettier_1.default.format(source, const_1.PRETTIER_DEFAULT));
    }
};
//# sourceMappingURL=createListModulesForLoadOnDemand.js.map