"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = require("path");
const prettier_1 = __importDefault(require("prettier"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const const_1 = require("../../const");
const bundleNaming_1 = require("../../helpers/bundleNaming");
const getBundleIntrospection_1 = require("./getBundleIntrospection");
exports.createListOfLoadOnDemand = async (CWD, isDevelopment) => {
    const bundleIntrospections = await getBundleIntrospection_1.getBundleIntrospections(CWD, isDevelopment);
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const content = [];
    for (const { pkgSnakeName, hasDll, hasBrowserLib, assetsPath, willLoadOnDemand, } of bundleIntrospections) {
        if (willLoadOnDemand) {
            const dllName = bundleNaming_1.getDLLRuntimeName(pkgSnakeName);
            const libName = bundleNaming_1.getLIBRuntimeName(pkgSnakeName);
            const libPublicPath = require(assetsPath.lib)[libName].js;
            if (hasDll && hasBrowserLib) {
                const dllPublicPath = require(assetsPath.dll)[dllName].js;
                content.push(`export const ${pkgSnakeName}: LoadOnDemand = ` +
                    `{ dll: [ "${dllName}" , "${dllPublicPath}" ], lib: [ "${libName}", "${libPublicPath}" ] };`);
            }
            if (!hasDll && hasBrowserLib) {
                content.push(`export const ${pkgSnakeName}: LoadOnDemand = { dll: [], lib: [ "${libName}", "${libPublicPath}" ] };`);
            }
        }
    }
    if (content.length > 0) {
        content.unshift("export declare type LoadOnDemand = { dll: string[], lib: string[] };");
        fs_1.writeFileSync(path_1.resolve(CWD, rearguardConfig.getContext(), const_1.LIST_OF_LOAD_ON_DEMAND), prettier_1.default.format(content.join(" "), const_1.PRETTIER_DEFAULT));
    }
};
//# sourceMappingURL=createListOfLoadOnDemand.js.map