"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const RearguardDevConfig_1 = require("../../configs/RearguardDevConfig");
const dependencyPaths_1 = require("../../helpers/dependencyPaths");
const getSortedListOfDependencies_1 = require("./getSortedListOfDependencies");
exports.getOutdatedDependency = async (CWD) => {
    console.log(chalk_1.default.bold.grey(`[ CHECK_OUTDATE_DEPENDENCY ]`));
    const outdatedDependency = new Set();
    const globalNodeModulePath = dependencyPaths_1.getGlobalNodeModulePath();
    const localNodeModulePath = dependencyPaths_1.getLocalNodeModulePath(CWD);
    for (const i_module of await getSortedListOfDependencies_1.getSortedListOfDependencies(CWD)) {
        const i_modulePath = path_1.default.resolve(globalNodeModulePath, i_module);
        if (fs_1.default.existsSync(i_modulePath)) {
            const i_moduleLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(i_modulePath);
            if (await i_moduleLocalConfig.hasLastBuildTime()) {
                const i_moduleProjectDeps = await getSortedListOfDependencies_1.getSortedListOfDependencies(i_modulePath);
                const i_moduleLastBuildTime = await i_moduleLocalConfig.getLastBuildTime();
                for (let k = i_moduleProjectDeps.length - 1; k >= 0; k--) {
                    const k_modulePath = path_1.default.resolve(globalNodeModulePath, i_moduleProjectDeps[k]);
                    if (fs_1.default.existsSync(k_modulePath)) {
                        const k_moduleLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(k_modulePath);
                        if (await k_moduleLocalConfig.hasLastBuildTime()) {
                            const k_moduleLastBuildTime = await k_moduleLocalConfig.getLastBuildTime();
                            if (i_moduleLastBuildTime.isSameOrBefore(k_moduleLastBuildTime)) {
                                console.log(chalk_1.default.bold.grey(`[ ${i_modulePath} ][ OUTDATED ]`));
                                outdatedDependency.add(i_modulePath);
                                break;
                            }
                        }
                        else {
                            outdatedDependency.add(i_modulePath);
                        }
                    }
                    else {
                        console.log(chalk_1.default.bold.grey(`[ ${k_modulePath} ][ NOT_FOUND ]`));
                    }
                }
            }
            else {
                outdatedDependency.add(i_modulePath);
            }
        }
        else if (fs_1.default.existsSync(path_1.default.resolve(localNodeModulePath, i_module))) {
            console.log(chalk_1.default.grey(`[ ${i_module} ][ LOCAL_INSTALLED ]`));
        }
        else {
            console.log(chalk_1.default.grey(`[ ${i_module} ][ NOT_FOUND ]`));
        }
    }
    console.log(chalk_1.default.grey(``));
    return outdatedDependency;
};
//# sourceMappingURL=getOutdatedDependency.js.map