"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const webpack_1 = __importDefault(require("webpack"));
const webpack_dev_server_1 = __importDefault(require("webpack-dev-server"));
const getWebpackDevServerConfig_1 = require("../../webpack/components/getWebpackDevServerConfig");
const webpack_config_app_1 = require("../../webpack/webpack.config.app");
const RearguardDevConfig_1 = require("../../configs/RearguardDevConfig");
exports.runWebpackDevServer = async (CWD, isDevelopment, isBuild, isDebug) => {
    console.log(chalk_1.default.bold.blue(`[ RUN WEBPACK-DEV-SERVER ]`));
    console.log("");
    const rearguardLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(CWD);
    const webpackConfig = await webpack_config_app_1.getAppWebpackConfig(CWD, isDevelopment, isBuild, isDebug);
    const webpackDevServerConfig = await getWebpackDevServerConfig_1.getWebpackDevServerConfig(CWD, isDevelopment);
    const compiler = webpack_1.default(webpackConfig);
    const wds = new webpack_dev_server_1.default(compiler, webpackDevServerConfig);
    const { host, port } = await rearguardLocalConfig.getWDSConfig();
    process.on("SIGINT", () => {
        wds.close();
        process.exit(0);
    });
    process.on("exit", () => {
        wds.close();
    });
    process.on("uncaughtException", () => {
        wds.close();
        process.exit(1);
    });
    process.on("unhandledRejection", () => {
        wds.close();
        process.exit(1);
    });
    wds.listen(port, host);
};
//# sourceMappingURL=runWebpackDevServer.js.map