"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const TypescriptConfig_1 = require("../../configs/TypescriptConfig");
const const_1 = require("../../const");
const gitignore_1 = require("../../templates/gitignore");
const lint_1 = require("../../templates/lint");
exports.setConfigs = async (options, CWD = process.cwd()) => {
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const typescriptConfig = new TypescriptConfig_1.TypescriptConfig(CWD);
    const typescriptConfigForJest = new TypescriptConfig_1.TypescriptConfig(CWD, "tsconfig.jest.json");
    const isNode = rearguardConfig.isNode();
    const isBrowser = rearguardConfig.isBrowser();
    const isIsomorphic = rearguardConfig.isIsomorphic();
    const isLib = rearguardConfig.isLib();
    const isApp = rearguardConfig.isApp();
    const context = rearguardConfig.getContext();
    const bin = rearguardConfig.getBin();
    const include = new Set([context]);
    const includeForJest = new Set([
        `${context}/**/*`,
        `${const_1.TESTS_DIR_NAME}/**/*`,
        `__${const_1.TESTS_DIR_NAME}__/**/*`,
    ]);
    const exclude = new Set(["node_modules"]);
    if (isApp) {
        exclude.add(const_1.DISTRIBUTIVE_DIR_NAME);
    }
    if (isBrowser || isIsomorphic) {
        exclude.add(const_1.DLL_BUNDLE_DIR_NAME);
        exclude.add(const_1.LIB_BUNDLE_DIR_NAME);
        exclude.add(const_1.LIB_DIR_NAME);
    }
    if (isNode) {
        if (isLib) {
            exclude.add(const_1.LIB_DIR_NAME);
        }
        if (isApp) {
            include.add(bin);
            includeForJest.add(`${bin}/**/*`);
        }
    }
    if ((isNode && isApp) || (isBrowser && isApp)) {
        exclude.add(const_1.BUILD_ASSETS_DIR_NAME);
    }
    await typescriptConfig.init(rearguardConfig.isOverwriteTSConfig() || options.force);
    await typescriptConfig.setBaseUrl(context);
    await typescriptConfig.setInclude(Array.from(include));
    await typescriptConfig.setExclude([
        ...Array.from(exclude),
        `${context}/**/*.test.ts`,
        `${context}/**/*.spec.ts`,
        `__${const_1.TESTS_DIR_NAME}__/**/*`,
    ]);
    await typescriptConfigForJest.init(rearguardConfig.isOverwriteTSTestConfig() || options.force);
    await typescriptConfigForJest.setBaseUrl(context);
    await typescriptConfigForJest.setInclude(Array.from(includeForJest));
    await typescriptConfigForJest.setExclude(Array.from(exclude));
    await typescriptConfigForJest.setTypes(["jest"]);
    if (isNode) {
        await lint_1.nodeLibLintTemplate.render({
            force: rearguardConfig.isOverwriteLintConfig() || options.force,
        });
    }
    if (isBrowser || isIsomorphic) {
        await lint_1.browserOrIsomorphicLintTemplate.render({
            force: rearguardConfig.isOverwriteLintConfig() || options.force,
        });
    }
    lint_1.lintIgnoreTemplate.render({
        force: rearguardConfig.isOverwriteLintConfig() || options.force,
    });
    await gitignore_1.gitignoreTemplate.render({
        publish_to_git: rearguardConfig.isPublishToGit(),
        list_for_load_on_demand: const_1.LIST_OF_LOAD_ON_DEMAND,
        force: rearguardConfig.isOverwriteGitIgnore() || options.force,
    });
};
//# sourceMappingURL=setConfigs.js.map