"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@rtcts/utils");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const const_1 = require("../../const");
const getSortedListOfDependencies_1 = require("./getSortedListOfDependencies");
const vsCode_1 = require("../../templates/vsCode");
const exists = util_1.promisify(fs_1.default.exists);
const readFile = util_1.promisify(fs_1.default.readFile);
const writeFile = util_1.promisify(fs_1.default.writeFile);
exports.getMonorepoWorkDirectory = async (CWD) => {
    if (CWD === "/") {
        return;
    }
    if (!(await exists(path_1.default.resolve(CWD, "package.json")))) {
        return exports.getMonorepoWorkDirectory(path_1.default.resolve(CWD, ".."));
    }
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    if (rearguardConfig.isMono()) {
        return CWD;
    }
    else {
        return exports.getMonorepoWorkDirectory(path_1.default.resolve(CWD, ".."));
    }
};
exports.updateVSCodeSettingsForMonoRepo = async (CWD) => {
    const MWD = await exports.getMonorepoWorkDirectory(CWD);
    if (utils_1.isString(MWD)) {
        const rearguardConfig = new RearguardConfig_1.RearguardConfig(MWD);
        const components = rearguardConfig.getComponents();
        const sortedListOfMonoComponents = await getSortedListOfDependencies_1.getSortedListOfMonoComponents(MWD, components);
        const workDirectories = [];
        for (const pathToComponent of sortedListOfMonoComponents) {
            workDirectories.push(`./${path_1.default.relative(MWD, pathToComponent)}`);
        }
        const vsCodeSettingsPath = path_1.default.resolve(MWD, const_1.VS_CODE_SETTINGS);
        if (await exists(vsCodeSettingsPath)) {
            const vsCodeSettings = JSON.parse(await readFile(vsCodeSettingsPath, { encoding: "utf-8" }));
            vsCodeSettings["eslint.workingDirectories"] = workDirectories.map((workDirectory) => ({
                directory: workDirectory,
                changeProcessCWD: true,
            }));
            await writeFile(vsCodeSettingsPath, JSON.stringify(vsCodeSettings, null, 2), {
                encoding: "utf-8",
            });
        }
    }
    else if (await exists(path_1.default.resolve(CWD, "package.json"))) {
        const vsCodeSettingsPath = path_1.default.resolve(CWD, const_1.VS_CODE_SETTINGS);
        if (!(await exists(vsCodeSettingsPath))) {
            await vsCode_1.vsCodeSettingsTemplate.render();
            await vsCode_1.vsCodeExtensionsTemplate.render();
        }
        const vsCodeSettings = JSON.parse(await readFile(vsCodeSettingsPath, { encoding: "utf-8" }));
        vsCodeSettings["eslint.alwaysShowStatus"] = true;
        vsCodeSettings["eslint.enable"] = true;
        vsCodeSettings["eslint.packageManager"] = "npm";
        vsCodeSettings["eslint.workingDirectories"] = ["."];
        await writeFile(vsCodeSettingsPath, JSON.stringify(vsCodeSettings, null, 2), {
            encoding: "utf-8",
        });
    }
};
//# sourceMappingURL=updateVSCodeSettingsForMonoRepo.js.map