"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const processQueue_1 = require("../../helpers/processQueue");
const buildOutdatedDependency_1 = require("../procedures/build/buildOutdatedDependency");
const buildUnfinishedDependencies_1 = require("../procedures/build/buildUnfinishedDependencies");
const copyBundlesToProject_1 = require("../procedures/copyBundlesToProject");
const copyGlobalLinkedModules_1 = require("../procedures/copyGlobalLinkedModules");
const createListOfLoadOnDemand_1 = require("../procedures/createListOfLoadOnDemand");
const deleteExternalBundles_1 = require("../procedures/deleteExternalBundles");
const runWebpackDevServer_1 = require("../procedures/runWebpackDevServer");
const watchLinkedModules_1 = require("../procedures/watchLinkedModules");
async function start_browser_lib(options) {
    console.log(chalk_1.default.bold.blue(`[ BROWSER LIB ][ START ]`));
    console.log("");
    const CWD = process.cwd();
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const name = rearguardConfig.getName();
    await processQueue_1.processQueue.getInQueue(name);
    await buildUnfinishedDependencies_1.buildUnfinishedDependencies(CWD);
    await buildOutdatedDependency_1.buildOutdatedDependency(CWD);
    await deleteExternalBundles_1.deleteExternalBundles(CWD);
    await copyGlobalLinkedModules_1.copyGlobalLinkedModules(CWD);
    await copyBundlesToProject_1.copyBundlesToProject(CWD);
    await createListOfLoadOnDemand_1.createListOfLoadOnDemand(CWD, true);
    await watchLinkedModules_1.watchLinkedModules(CWD);
    await processQueue_1.processQueue.getOutQueue(name);
    await runWebpackDevServer_1.runWebpackDevServer(CWD, !options.release, false, options.debug);
}
exports.start_browser_lib = start_browser_lib;
//# sourceMappingURL=start_browser_lib.js.map