"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const RearguardDevConfig_1 = require("../../configs/RearguardDevConfig");
const const_1 = require("../../const");
const pubSub_1 = require("../../helpers/pubSub");
const getWebpackStats_1 = require("./getWebpackStats");
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
exports.getWebpackDevServerConfig = async (CWD, isDevelopment) => {
    const rearguardLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(CWD);
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const context = rearguardConfig.getContext();
    const entry = rearguardConfig.getEntry();
    const { proxy } = await rearguardLocalConfig.getWDSConfig();
    const pathToEntryPoint = path_1.default.resolve(CWD, context, entry);
    let needReloadBrowser = false;
    return {
        http2: true,
        compress: true,
        contentBase: [const_1.DLL_BUNDLE_DIR_NAME, const_1.LIB_BUNDLE_DIR_NAME, const_1.PUBLIC_DIR_NAME],
        watchContentBase: false,
        useLocalIp: false,
        before(app, server) {
            pubSub_1.pubSub.on(pubSub_1.events.SYNCED, () => {
                if (fs_1.default.existsSync(pathToEntryPoint)) {
                    let content = fs_1.default.readFileSync(pathToEntryPoint, { encoding: "utf-8" });
                    const title = "// HACK for forcing invalidation of the webpack compiler, timestamp:";
                    const start = content.indexOf(title);
                    if (start !== -1) {
                        content = content.substring(0, start);
                    }
                    else {
                        content += `\r`;
                    }
                    content += `${title} ${Date.now()}`;
                    needReloadBrowser = true;
                    fs_1.default.writeFileSync(pathToEntryPoint, content);
                }
            });
            pubSub_1.pubSub.on(pubSub_1.events.RELOAD_BROWSER, () => {
                if (needReloadBrowser) {
                    server.middleware.waitUntilValid(() => {
                        console.log("");
                        console.log("[ WDS ][ RELOAD_BROWSER ]");
                        console.log("");
                        server.sockWrite(server.sockets, "content-changed");
                        needReloadBrowser = false;
                    });
                }
            });
        },
        historyApiFallback: true,
        hot: isDevelopment,
        liveReload: isDevelopment,
        overlay: false,
        proxy,
        publicPath: "/",
        stats: getWebpackStats_1.getWebpackStats(CWD),
        headers: {
            ["Cache-Control"]: "no-transform",
        },
    };
};
//# sourceMappingURL=getWebpackDevServerConfig.js.map