"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const webpack_1 = __importDefault(require("webpack"));
const getBundleIntrospection_1 = require("../../../components/procedures/getBundleIntrospection");
const RearguardConfig_1 = require("../../../configs/RearguardConfig");
const bundleNaming_1 = require("../../../helpers/bundleNaming");
exports.getDllPlugin = (CWD, isDevelopment, options = {}) => {
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const contextPath = path_1.default.resolve(CWD, rearguardConfig.getContext());
    const snakeName = rearguardConfig.getSnakeName();
    return new webpack_1.default.DllPlugin({
        context: contextPath,
        name: bundleNaming_1.getDLLRuntimeName(snakeName),
        path: bundleNaming_1.getDLLManifestPath(CWD, snakeName, isDevelopment),
        format: true,
        ...options,
    });
};
exports.getDllReferencePlugin = async (CWD, isDevelopment) => {
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const pkgSnakeName = rearguardConfig.getSnakeName();
    const contextPath = path_1.default.resolve(CWD, rearguardConfig.getContext());
    const bundleIntrospection = await getBundleIntrospection_1.getBundleIntrospections(CWD, isDevelopment);
    const result = [];
    for (const { hasDll, willLoadOnDemand, dllManifestPath, bundleRuntimeName, } of bundleIntrospection) {
        if (!willLoadOnDemand && hasDll) {
            if (path_1.default.isAbsolute(dllManifestPath) && fs_1.default.existsSync(dllManifestPath)) {
                result.push(new webpack_1.default.DllReferencePlugin({
                    context: contextPath,
                    manifest: dllManifestPath,
                    name: bundleRuntimeName.dll,
                }));
            }
            else {
                console.log(chalk_1.default.red(`[ DllReferencePlugin ][ ERROR ][ MANIFEST_NOT_FOUND: ${dllManifestPath} ]`));
                process.exit(1);
            }
        }
    }
    const dllManifestPathForCurrentProject = bundleNaming_1.getDLLManifestPath(CWD, pkgSnakeName, isDevelopment);
    if (fs_1.default.existsSync(dllManifestPathForCurrentProject)) {
        result.push(new webpack_1.default.DllReferencePlugin({
            context: contextPath,
            manifest: dllManifestPathForCurrentProject,
            name: bundleNaming_1.getDLLRuntimeName(pkgSnakeName),
        }));
    }
    return result;
};
//# sourceMappingURL=dllPlugins.js.map