"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const html_webpack_plugin_1 = __importDefault(require("html-webpack-plugin"));
const path_1 = __importDefault(require("path"));
const getBundleIntrospection_1 = require("../../../components/procedures/getBundleIntrospection");
const RearguardConfig_1 = require("../../../configs/RearguardConfig");
const bundleNaming_1 = require("../../../helpers/bundleNaming");
const InlineChunkHtmlPlugin_1 = require("./InlineChunkHtmlPlugin");
const InterpolateHtmlPlugin_1 = require("./InterpolateHtmlPlugin");
const utils_1 = require("@rtcts/utils");
const chalk_1 = __importDefault(require("chalk"));
const getENV_1 = require("../../../components/procedures/getENV");
const util_1 = require("util");
const pubSub_1 = require("../../../helpers/pubSub");
const exists = util_1.promisify(fs_1.default.exists);
const readFile = util_1.promisify(fs_1.default.readFile);
class ComputeDataForHWP {
    constructor(CWD, isDevelopment) {
        this.CWD = CWD;
        this.isDevelopment = isDevelopment;
        this.rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
        this.apply = this.apply.bind(this);
    }
    apply(compiler) {
        compiler.hooks.compilation.tap("compute_data_for_html_webpack_plugin", (compilation) => {
            html_webpack_plugin_1.default.getHooks(compilation).beforeAssetTagGeneration.tapAsync("html_webpack_plugin__inject_externals", async (data, callback) => {
                const snakeName = this.rearguardConfig.getSnakeName();
                const dllAssetsPath = bundleNaming_1.getDLLAssetsPath(this.CWD, snakeName, this.isDevelopment);
                const willLoadOnDemand = this.rearguardConfig.willLoadOnDemand();
                const bundleIntrospection = await getBundleIntrospection_1.getBundleIntrospections(this.CWD, this.isDevelopment);
                const assets = { js: [], css: [] };
                for (const { hasDll, hasBrowserLib, willLoadOnDemand, assetsPath, pkgSnakeName, } of bundleIntrospection) {
                    if (!willLoadOnDemand) {
                        if (hasDll && (await exists(assetsPath.dll))) {
                            const content = await readFile(assetsPath.dll, { encoding: "utf-8" });
                            const source = JSON.parse(content);
                            const dll = source[bundleNaming_1.getDLLRuntimeName(pkgSnakeName)];
                            if (utils_1.isString(dll.js)) {
                                assets.js.push(dll.js);
                            }
                            if (utils_1.isString(dll.css)) {
                                assets.css.push(dll.css);
                            }
                        }
                        if (hasBrowserLib && (await exists(assetsPath.lib))) {
                            const content = await readFile(assetsPath.lib, { encoding: "utf-8" });
                            const source = JSON.parse(content);
                            const lib = source[bundleNaming_1.getLIBRuntimeName(pkgSnakeName)];
                            if (utils_1.isString(lib.js)) {
                                assets.js.push(lib.js);
                            }
                            if (utils_1.isString(lib.css)) {
                                assets.css.push(lib.css);
                            }
                        }
                    }
                }
                if (!willLoadOnDemand && (await exists(dllAssetsPath))) {
                    const content = await readFile(dllAssetsPath, { encoding: "utf-8" });
                    const source = JSON.parse(content);
                    const dll = source[bundleNaming_1.getDLLRuntimeName(snakeName)];
                    assets.js.push(dll.js);
                }
                data.assets.js = [...assets.js, ...data.assets.js];
                data.assets.css = [...assets.css, ...data.assets.css];
                console.log("");
                console.log("");
                console.log(chalk_1.default.bold.green("[ HtmlWebpackPlugin ][ BUILD ][ index.html ]"));
                console.log("");
                for (const css of data.assets.css) {
                    console.log(chalk_1.default.green(`[ CSS ][ ${css} ]`));
                }
                for (const js of data.assets.js) {
                    console.log(chalk_1.default.green(`[ JS ][ ${js} ]`));
                }
                console.log("");
                callback(null, data);
            });
            html_webpack_plugin_1.default.getHooks(compilation).afterEmit.tapPromise("html_webpack_plugin__reload_browser_after_emit", async () => {
                pubSub_1.pubSub.emit(pubSub_1.events.RELOAD_BROWSER);
            });
        });
    }
}
exports.getHtmlWebpackPlugin = (CWD, isDevelopment) => {
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const isBrowser = rearguardConfig.isBrowser();
    const isApp = rearguardConfig.isApp();
    const { publicPath } = rearguardConfig.getOutput();
    let template = path_1.default.resolve(CWD, bundleNaming_1.getPublicDirPath(CWD), "index.html");
    if (!(isBrowser && isApp)) {
        template = path_1.default.resolve(__dirname, "../../../templates/indexHtml", "index.html");
    }
    let PUBLIC_URL = path_1.default.normalize(publicPath);
    if (PUBLIC_URL[PUBLIC_URL.length - 1] === "/") {
        PUBLIC_URL = PUBLIC_URL.slice(0, -1);
    }
    if (isDevelopment) {
        PUBLIC_URL = "";
    }
    return [
        new html_webpack_plugin_1.default(Object.assign({}, {
            inject: true,
            template,
        }, {}, !isDevelopment
            ? {
                minify: {
                    removeComments: true,
                    collapseWhitespace: true,
                    removeRedundantAttributes: true,
                    useShortDoctype: true,
                    removeEmptyAttributes: true,
                    removeStyleLinkTypeAttributes: true,
                    keepClosingSlash: true,
                    minifyJS: true,
                    minifyCSS: true,
                    minifyURLs: true,
                },
            }
            : undefined)),
        new ComputeDataForHWP(CWD, isDevelopment),
        ...(isDevelopment ? [] : [new InlineChunkHtmlPlugin_1.InlineChunkHtmlPlugin(html_webpack_plugin_1.default, [/runtime-.+[.]js/])]),
        new InterpolateHtmlPlugin_1.InterpolateHtmlPlugin(html_webpack_plugin_1.default, {
            PUBLIC_URL,
            ...getENV_1.getENV(CWD).interpolationHTML,
        }),
    ];
};
//# sourceMappingURL=getHtmlWebpackPlugin.js.map